@@ -17,7 +17,8 @@ from rig.place_and_route.exceptions import \
 
 from rig.place_and_route.place.utils import \
     add_resources, subtract_resources, overallocated, \
-    apply_reserve_resource_constraint
+    apply_reserve_resource_constraint, apply_same_chip_constraints, \
+    finalise_same_chip_constraints
 
 
 """
@@ -35,7 +36,7 @@ def _initial_placement(movable_vertices, vertices_resources, machine, random):
     movable_vertices : [vertex, ...]
         A list of the vertices to be given a random initial placement.
     vertices_resources : {vertex: {resource: value, ...}, ...}
-    machine : :py:class:`rig.machine.Machine`
+    machine : :py:class:`rig.place_and_route.Machine`
         A machine object describing the machine into which the vertices should
         be placed.
 
@@ -119,7 +120,7 @@ def _net_cost(net, placements, has_wrap_around_links, machine):
     net : :py:class:`rig.netlist.Net`
     placements : {vertex: (x, y), ...}
     has_wrap_around_links : bool
-    machine : :py:class:`rig.machine.Machine`
+    machine : :py:class:`rig.place_and_route.Machine`
 
     Returns
     -------
@@ -207,7 +208,7 @@ def _vertex_net_cost(vertex, v2n, placements, has_wrap_around_links, machine):
     v2n : {vertex: [:py:class:`rig.netlist.Net`, ...], ...}
     placements : {vertex: (x, y), ...}
     has_wrap_around_links : bool
-    machine : :py:class:`rig.machine.Machine`
+    machine : :py:class:`rig.place_and_route.Machine`
 
     Returns
     -------
@@ -236,7 +237,7 @@ def _get_candidate_swap(resources, location,
     l2v : {(x, y): [vertex, ...], ...}
     vertices_resources : {vertex: {resource: value, ...}, ...}
     fixed_vertices : {vertex: (x, y), ...}
-    machine : :py:class:`rig.machine.Machine`
+    machine : :py:class:`rig.place_and_route.Machine`
 
     Returns
     -------
@@ -294,7 +295,7 @@ def _swap(vas, vas_location, vbs, vbs_location, l2v, vertices_resources,
     l2v : {(x, y): [vertex, ...], ...}
     vertices_resources : {vertex: {resource: value, ...}, ...}
     placements : {vertex: (x, y), ...}
-    machine : :py:class:`rig.machine.Machine`
+    machine : :py:class:`rig.place_and_route.Machine`
     """
     # Get the lists of vertices at either location
     vas_location2v = l2v[vas_location]
@@ -360,7 +361,7 @@ def _step(vertices, d_limit, temperature, placements, l2v, v2n,
     vertices_resources : {vertex: {resource: value, ...}, ...}
     fixed_vertices : {vertex: (x, y), ...}
         The set of vertices which must not be moved.
-    machine : :py:class:`rig.machine.Machine`
+    machine : :py:class:`rig.place_and_route.Machine`
         Describes the state of the machine including the resources actually
         available on each chip given the current placements. Updated if a swap
         is made.
@@ -542,6 +543,8 @@ def place(vertices_resources, nets, machine, constraints,
     fixed_vertices = {}
 
     # Handle constraints
+    vertices_resources, nets, constraints, substitutions = \
+        apply_same_chip_constraints(vertices_resources, nets, constraints)
     for constraint in constraints:
         if isinstance(constraint, LocationConstraint):
             # Location constraints are handled by recording the set of fixed
@@ -586,6 +589,7 @@ def place(vertices_resources, nets, machine, constraints,
     # * No effort is to be made
     # * There are no nets (and moving things has no effect)
     if len(movable_vertices) == 0 or effort == 0.0 or len(nets) == 0:
+        finalise_same_chip_constraints(substitutions, placements)
         return placements
 
     # Location-to-Vertices: A lookup {(x, y): [vertex, ...], ...} giving the
@@ -724,4 +728,6 @@ def place(vertices_resources, nets, machine, constraints,
     logger.info("Anneal terminated after %d iterations with final cost %0.1f.",
                 iteration_count, current_cost)
 
+    finalise_same_chip_constraints(substitutions, placements)
+
     return placements
